@@ -54,7 +54,7 @@
 * actions in the queue in sequence.
 *
 */
-KDE_EXPORT class ActionQueue : public SyncAction
+class KDE_EXPORT ActionQueue : public SyncAction
 {
 Q_OBJECT
   
