@@ -388,7 +388,7 @@ protected:
 } ;
 
 /** A namespace containing only static helper methods. */
-namespace PluginUtility
+namespace PluginUtility KDE_EXPORT
 {
 	/** Searches the argument list for --foo=bar and returns bar, TQString() if not found.
 	* Don't include the -- in the argname. */
